==> v0.5.4.tar.gz: libarea/app/Languages/ru/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'Подробнее',
    'category'          => 'Категория',
    'categories'        => 'Категории',
    'audits'            => 'Аудит',
    'soft'              => 'Софт',
    'website'           => 'Сайт',
    'websites'          => 'Сайты',
    'on_website'        => 'На сайт',
    'deleted'           => 'Удаленные',
    'facets'            => 'Фасеты',
    'favorites'         => 'Закладки',
    'menu'              => 'Меню',
    'no'                => 'Нет',
    'yes'               => 'Да',
    'title'             => 'Название',
    'description'       => 'Описание',
    'catalog'           => 'Каталог',
    'find'              => 'Найти',
    'help'              => 'Подсказка',
    'deny_replies'      => 'Запретить ответы?',
    'posted'            => 'Размещен?',
    'necessarily'       => 'Обязательно к заполнению',
    'status'            => 'Статус ссылки',
    'there_program'     => 'Есть программа?',
    'there_forum'       => 'На сайте есть форум?',
    'there_portal'      => 'Это портал?',
    'there_blog'        => 'Это личный блог?',
    'there_reference'   => 'Это справочный сайт (энциклопедия)?',
    'there_goods'       => 'На сайте есть товары и услуги?',
    'hosted_github'     => 'Программа размещена на GitHub?',
    'url_github'        => 'URL адрес репозитория на GitHub',
    'related_posts'     => 'Связанные посты',
    'desc_formed'       => 'Описание формируется',
    'by_date'           => 'По дате',
    'top_view'          => 'По рейтингу',
    'new_sites'         => 'Новые сайты',
    'audits_view'       => 'Требуют рассмотрения',
    'deleted_view'      => 'Удалены',
    'my_website'        => 'Мои сайты',
    'no_website'        => 'Сайтов пока нет',
    'bookmarks'         => 'Мои закладки по сайтам',
    'bookmarks_view'    => 'Мои закладки',
    'no_bookmarks'      => 'Закладок пока нет',
    'answers'           => 'Ответы',
    'no_answers'        => 'Пока нет ответов...',
    'characters'        => 'Символов',
    'remove'            => 'Удалить',
    'reply'             => 'Ответить',
    'edit'              => 'Изменить',
    'cancel'            => 'Отменить',
    'add'               => 'Добавить',
    'markdown'          => 'Разметка Мarkdown',
    'recommended'       => 'Рекомендованные',
    'my_website_info'   => 'Список сайтов добавленных мной',
    'moderation'        => 'Модерация',
    'sign_in'           => 'Войти',
    'registration'      => 'Регистрация',
    'site_added'        => 'Сайт добавлен',

    'closed'            => 'Обсуждение сайта запрещено. Автор или персонал закрыл обсуждение.',

    'screenshot_time'   => 'Создание скриншота может занять некоторое время.',

    'audits_home_title' => 'Аудит сайтов',
    'audits_home_desc'  => 'Сайты на рассмотрении',
    'num_website'       => ['Сайт', 'Сайта', 'Сайтов'],

    'news'              => 'Новости и СМИ',
    'internet'          => 'Интернет',
    'culture'           => 'Культура и искусство',
    'software'          => 'Программы',
    'reference_info'    => 'Справочная информация',
    'reference_help'    => 'Энциклопедии, справочники',
    'science'           => 'Наука и образование',
    'business'          => 'Бизнес',
    'life'              => 'Домашний очаг',
    'cms'               => 'CMS',
    'life_help'         => 'Детям, животные, хобби...',
    'security'          => 'Безопасность...',
    'society'           => 'Общество и политика',

    'contact_information'   => 'Контактная информация',
    'telephone'             => 'Телефон',
    'email'                 => 'E-mail',
    'vk'                    => 'ВКонтакте (URL)',
    'telegram'              => 'Телеграм (URL)',

    'string_length'         => 'Некорректная длина {name}',
    'website_correctness'   => 'Адрес (URL) сайта не является корректным',
    'site_replay'           => 'Такой сайт уже есть в системе',

    'data_help'         => '<i class="gray-600">Формат заголовка:</i><br> «LibArea» — сообщество<br><br><i class="gray-600">Описание (без рекламы):</i><br> ...что есть на сайте?<i>',

    'add_category'      => 'Добавить категорию',
    'add_website'       => 'Добавить сайт',
    'edit_website'      => 'Изменить сайт',

    'sidebar_info'      => 'Каталог сайтов, систематизированных по тематическим рубрикам.',
    'banner_info'       => 'Каталог сайтов с аннотациями и скриншотами. <br>Фасетная рубрикация, поиск. Закладки по ресурсам с возможность голосовать за сайты, программы, рейтинг',

    'main_title'        => 'Каталог сайтов',
    'main_desc'         => 'Список сайтов в каталоге размещенных в хронологическом порядке. Возможность поиска, закладки, сортировка по популярности',

    'deleted_title'     => 'Удаленные сайты',
    'deleted_desc'      => '...',
    'audits_title'      => 'Аудит сайтов',
    'audits_desc'       => '...',

    'all'               => 'Все',
    'github'            => 'GitHub',
    'forum'             => 'Форумы',
    'blog'              => 'Блоги',
    'portal'            => 'Порталы',
    'reference'         => 'Энциклопедии',
    'goods'             => 'Товары и услуги',

    'top_title'         => '{name} — сайты по популярности',
    'top_desc'          => 'Анонсированные список сайтов по тематике {description_info}',
    'all_title'         => '{name} — рубрика, сайты по дате',
    'all_desc'          => 'Сайты в хронологическом порядке в рубрике {description_info}',
];

==> v0.5.6.tar.gz: libarea/app/Languages/ru/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'Подробнее',
    'category'          => 'Категория',
    'categories'        => 'Категории',
    'audits'            => 'Аудит',
    'soft'              => 'Софт',
    'website'           => 'Сайт',
    'websites'          => 'Сайты',
    'comments'          => 'Комментарии',
    'on_website'        => 'На сайт',
    'deleted'           => 'Удаленные',
    'facets'            => 'Фасеты',
    'favorites'         => 'Закладки',
    'menu'              => 'Меню',
    'no'                => 'Нет',
    'yes'               => 'Да',
    'title'             => 'Название',
    'description'       => 'Описание',
    'catalog'           => 'Каталог',
    'find'              => 'Найти',
    'help'              => 'Подсказка',
    'deny_replies'      => 'Запретить ответы?',
    'posted'            => 'Размещен?',
    'necessarily'       => 'Обязательно к заполнению',
    'status'            => 'Статус',
    'refresh'           => 'Обновить',
    'there_program'     => 'Есть программа?',
    'there_forum'       => 'На сайте есть форум?',
    'there_portal'      => 'Это портал?',
    'there_blog'        => 'Это личный блог?',
    'there_reference'   => 'Это справочный сайт (энциклопедия)?',
    'there_goods'       => 'На сайте есть товары и услуги?',
    'hosted_github'     => 'Программа размещена на GitHub?',
    'url_github'        => 'URL адрес репозитория на GitHub',
    'related_posts'     => 'Связанные посты',
    'desc_formed'       => 'Описание формируется',
    'by_date'           => 'По дате',
    'top'               => 'ТОП',
    'top_view'          => 'По рейтингу',
    'new_sites'         => 'Новые сайты',
    'audits_view'       => 'Требуют рассмотрения',
    'deleted_view'      => 'Удалены',
    'my_website'        => 'Мои сайты',
    'no_website'        => 'Сайтов пока нет',
    'bookmarks'         => 'Мои закладки по сайтам',
    'bookmarks_view'    => 'Мои закладки',
    'no_bookmarks'      => 'Закладок пока нет',
    'answers'           => 'Ответы',
    'no_answers'        => 'Пока нет ответов...',
    'characters'        => 'Символов',
    'remove'            => 'Удалить',
    'reply'             => 'Ответить',
    'edit'              => 'Изменить',
    'cancel'            => 'Отменить',
    'add'               => 'Добавить',
    'markdown'          => 'Разметка Мarkdown',
    'recommended'       => 'Рекомендованные',
    'my_website_info'   => 'Список сайтов добавленных мной',
    'moderation'        => 'Модерация',
    'sign_in'           => 'Войти',
    'registration'      => 'Регистрация',
    'site_added'        => 'Сайт добавлен',

    'closed'            => 'Обсуждение сайта запрещено. Автор или персонал закрыл обсуждение.',

    'screenshot_time'   => 'Создание скриншота может занять некоторое время.',

    'audits_home_title' => 'Аудит сайтов',
    'audits_home_desc'  => 'Сайты на рассмотрении',
    'num_website'       => ['Сайт', 'Сайта', 'Сайтов'],

    'news'              => 'Новости и СМИ',
    'internet'          => 'Интернет',
    'culture'           => 'Культура и искусство',
    'software'          => 'Программы',
    'reference_info'    => 'Справочная информация',
    'reference_help'    => 'Энциклопедии, справочники',
    'science'           => 'Наука и образование',
    'business'          => 'Бизнес',
    'life'              => 'Домашний очаг',
    'cms'               => 'CMS',
    'life_help'         => 'Детям, животные, хобби...',
    'security'          => 'Безопасность...',
    'society'           => 'Общество и политика',

    'contact_information'   => 'Контактная информация',
    'telephone'             => 'Телефон',
    'email'                 => 'E-mail',
    'vk'                    => 'ВКонтакте (URL)',
    'telegram'              => 'Телеграм (URL)',

    'string_length'         => 'Некорректная длина {name}',
    'website_correctness'   => 'Адрес (URL) сайта не является корректным',
    'site_replay'           => 'Такой сайт уже есть в системе',

    'data_help'         => '<i class="gray-600">Формат заголовка:</i><br> «LibArea» — сообщество<br><br><i class="gray-600">Описание (без рекламы):</i><br> ...что есть на сайте?<i>',
    'admin_help'         => 'Закрытый раздел доступный только персоналу...',

    'add_category'      => 'Добавить категорию',
    'add_website'       => 'Добавить сайт',
    'edit_website'      => 'Изменить сайт',

    'sidebar_info'      => 'Каталог сайтов, систематизированных по тематическим рубрикам.',
    'banner_info'       => 'Каталог сайтов с аннотациями и скриншотами. <br>Фасетная рубрикация, поиск. Закладки по ресурсам с возможность голосовать за сайты, программы, рейтинг',

    'main_title'        => 'Каталог сайтов',
    'main_desc'         => 'Список сайтов в каталоге размещенных в хронологическом порядке. Возможность поиска, закладки, сортировка по популярности',

    'deleted_title'     => 'Удаленные сайты',
    'audits_title'      => 'Аудит сайтов',

    'all'               => 'Все',
    'github'            => 'GitHub',
    'forum'             => 'Форумы',
    'blog'              => 'Блоги',
    'portal'            => 'Порталы',
    'reference'         => 'Энциклопедии',
    'goods'             => 'Товары и услуги',

    'top_title'         => '{name} — сайты по популярности',
    'top_desc'          => 'Анонсированные список сайтов по тематике {description_info}',
    'all_title'         => '{name} — рубрика, сайты по дате',
    'all_desc'          => 'Сайты в хронологическом порядке в рубрике {description_info}',
];
